@@ -7,12 +7,13 @@ EVE_GROUP_ID_CONTROL_TOWER = 365
 EVE_GROUP_ID_FUEL_BLOCK = 1136
 EVE_GROUP_ID_ENGINERING_COMPLEX = 1404
 EVE_GROUP_ID_REFINERY = 1406
-EVE_GROUP_ID_JUMP_GATE = 1408
 EVE_GROUP_ID_CITADEL = 1657
 
 EVE_TYPE_ID_POCO = 2233
+EVE_TYPE_ID_LIQUID_OZONE = 16273
+EVE_TYPE_ID_STRONTIUM = 16275
 EVE_TYPE_ID_TCU = 32226
 EVE_TYPE_ID_IHUB = 32458
-EVE_TYPE_ID_STRONTIUM = 16275
+EVE_TYPE_ID_JUMP_GATE = 35841
 
 EVE_CORPORATION_ID_DED = 1000137
