@@ -170,6 +170,8 @@ class NotificationBaseEmbed:
             return NotificationStructureOnline(notification)
         elif notif_type == NotificationType.STRUCTURE_FUEL_ALERT:
             return NotificationStructureFuelAlert(notification)
+        elif notif_type == NotificationType.STRUCTURE_JUMP_FUEL_ALERT:
+            return NotificationStructureJumpFuelAlert(notification)
         elif notif_type == NotificationType.STRUCTURE_REFUELED_EXTRA:
             return NotificationStructureRefuledExtra(notification)
         elif notif_type == NotificationType.STRUCTURE_SERVICES_OFFLINE:
@@ -364,6 +366,23 @@ class NotificationStructureFuelAlert(NotificationStructureEmbed):
         self._color = Webhook.Color.WARNING
 
 
+class NotificationStructureJumpFuelAlert(NotificationStructureEmbed):
+    def __init__(self, notification: Notification) -> None:
+        super().__init__(notification)
+        self._title = gettext("Jump gate low on Liquid Ozone")
+        threshold_str = f"{self._parsed_text['threshold']:,}"
+        quantity_str = f"{self._structure.jump_fuel_quantity():,}"
+        self._description += gettext(
+            "is below %(threshold)s units on Liquid Ozone.\n"
+            "Remaining units: %(remaining)s."
+            % {
+                "threshold": f"{Webhook.text_bold(threshold_str)}",
+                "remaining": f"{Webhook.text_bold(quantity_str)}",
+            }
+        )
+        self._color = Webhook.Color.WARNING
+
+
 class NotificationStructureRefuledExtra(NotificationStructureEmbed):
     def __init__(self, notification: Notification) -> None:
         super().__init__(notification)
