@@ -90,8 +90,11 @@ class NotificationType(models.TextChoices):
         "Upwell structure went low power"
     )
     STRUCTURE_UNANCHORING = "StructureUnanchoring", _("Upwell structure unanchoring")
-    STRUCTURE_FUEL_ALERT = "StructureFuelAlert", _("Upwell structure fuel alert")
+    STRUCTURE_FUEL_ALERT = "FuelAlert", _("Upwell structure fuel alert")
     STRUCTURE_REFUELED_EXTRA = "StructureRefueledExtra", _("Upwell structure refueled")
+    STRUCTURE_JUMP_FUEL_ALERT = "StructureJumpFuelAlert", _(
+        "Upwell structure jump fuel alert"
+    )
     STRUCTURE_UNDER_ATTACK = "StructureUnderAttack", _(
         "Upwell structure is under attack"
     )
@@ -185,6 +188,7 @@ class NotificationType(models.TextChoices):
     @classproperty
     def esi_notifications(cls) -> set:
         my_set = set(cls.values)
+        my_set.discard(cls.STRUCTURE_JUMP_FUEL_ALERT)
         my_set.discard(cls.STRUCTURE_REFUELED_EXTRA)
         my_set.discard(cls.TOWER_REFUELED_EXTRA)
         return my_set
@@ -1010,15 +1014,18 @@ class Notification(models.Model):
             kwargs["timestamp"] = now()
         if "last_updated" not in kwargs:
             kwargs["last_updated"] = now()
+        threshold = kwargs.pop("threshold") if "threshold" in kwargs else None
         if "text" not in kwargs:
             if notif_type in {
                 NotificationType.STRUCTURE_FUEL_ALERT,
                 NotificationType.STRUCTURE_REFUELED_EXTRA,
+                NotificationType.STRUCTURE_JUMP_FUEL_ALERT,
             }:
                 data = {
                     "solarsystemID": structure.eve_solar_system_id,
                     "structureID": structure.id,
                     "structureTypeID": structure.eve_type_id,
+                    "threshold": threshold,
                 }
             elif notif_type in {
                 NotificationType.TOWER_RESOURCE_ALERT_MSG,
@@ -1042,50 +1049,8 @@ class Notification(models.Model):
         return cls(**kwargs)
 
 
-class FuelAlert(models.Model):
-    """A generated notification alerting about fuel getting low in structures."""
-
-    structure = models.ForeignKey(
-        "Structure", on_delete=models.CASCADE, related_name="fuel_alerts"
-    )
-    config = models.ForeignKey(
-        "FuelAlertConfig", on_delete=models.CASCADE, related_name="fuel_alerts"
-    )
-    hours = models.PositiveIntegerField(
-        db_index=True,
-        help_text="number of hours before fuel expiration this alert was sent",
-    )
-    created_at = models.DateTimeField(auto_now_add=True)
-
-    class Meta:
-        constraints = [
-            models.UniqueConstraint(
-                fields=["structure", "config", "hours"],
-                name="functional_pk_fuelalert",
-            )
-        ]
-
-    def __str__(self) -> str:
-        return f"{self.structure}-{self.config}-{self.hours}"
-
-    def send_generated_notification(self):
-        notif_type = (
-            NotificationType.TOWER_RESOURCE_ALERT_MSG
-            if self.structure.is_starbase
-            else NotificationType.STRUCTURE_FUEL_ALERT
-        )
-        notif = Notification.create_from_structure(
-            structure=self.structure, notif_type=notif_type
-        )
-        notif.send_to_configured_webhooks(
-            ping_type_override=self.config.channel_ping_type,
-            use_color_override=True,
-            color_override=self.config.color,
-        )
-
-
-class FuelAlertConfig(models.Model):
-    """Configuration of fuel notifications."""
+class BaseFuelAlertConfig(models.Model):
+    """Configuration of structure fuel notifications."""
 
     channel_ping_type = models.CharField(
         max_length=2,
@@ -1098,6 +1063,37 @@ class FuelAlertConfig(models.Model):
             "or webhook configuration"
         ),
     )
+    color = models.IntegerField(
+        choices=Webhook.Color.choices,
+        default=Webhook.Color.WARNING,
+        blank=True,
+        null=True,
+        help_text="Context color of these notification on Discord",
+    )
+    is_enabled = models.BooleanField(
+        default=True,
+        help_text="Disabled configurations will not create any new alerts.",
+    )
+
+    class Meta:
+        abstract = True
+
+    def __str__(self) -> str:
+        return f"#{self.pk}"
+
+    def send_new_notifications(self, force: bool = False) -> None:
+        """Send new fuel notifications based on this config."""
+        raise NotImplementedError()
+
+    @staticmethod
+    def relevant_webhooks() -> models.QuerySet:
+        """Webhooks relevant for processing fuel notifications based on this config."""
+        raise NotImplementedError()
+
+
+class FuelAlertConfig(BaseFuelAlertConfig):
+    """Configuration of structure fuel notifications."""
+
     end = models.PositiveIntegerField(
         help_text="End of alerts in hours before fuel expires"
     )
@@ -1106,19 +1102,12 @@ class FuelAlertConfig(models.Model):
             "Notifications will be repeated every x hours. Set to 0 for no repeats"
         )
     )
-    color = models.IntegerField(
-        choices=Webhook.Color.choices,
-        default=Webhook.Color.WARNING,
-        blank=True,
-        null=True,
-    )
-    is_enabled = models.BooleanField(default=True)
     start = models.PositiveIntegerField(
         help_text="Start of alerts in hours before fuel expires"
     )
 
-    def __str__(self) -> str:
-        return f"#{self.pk}"
+    class Meta:
+        verbose_name = "structure fuel alert config"
 
     def clean(self) -> None:
         if self.start <= self.end:
@@ -1152,11 +1141,18 @@ class FuelAlertConfig(models.Model):
             or old_instance.end != self.end
             or old_instance.repeat != self.repeat
         ):
-            self.fuel_alerts.all().delete()
+            self.structure_fuel_alerts.all().delete()
 
     def send_new_notifications(self, force: bool = False) -> None:
         """Send new fuel notifications based on this config."""
-        for structure in self._structures_queryset():
+        structures = Structure.objects.filter(
+            eve_type__eve_group__eve_category_id__in=[
+                constants.EVE_CATEGORY_ID_STARBASE,
+                constants.EVE_CATEGORY_ID_STRUCTURE,
+            ],
+            fuel_expires_at__isnull=False,
+        )
+        for structure in structures:
             hours_left = structure.hours_fuel_expires
             if self.start >= hours_left >= self.end:
                 hours_last_alert = (
@@ -1174,17 +1170,6 @@ class FuelAlertConfig(models.Model):
                 if created or force:
                     notif.send_generated_notification()
 
-    @staticmethod
-    def _structures_queryset():
-        """Queryset of all relevant structures."""
-        return Structure.objects.filter(
-            eve_type__eve_group__eve_category_id__in=[
-                constants.EVE_CATEGORY_ID_STARBASE,
-                constants.EVE_CATEGORY_ID_STRUCTURE,
-            ],
-            fuel_expires_at__isnull=False,
-        )
-
     @staticmethod
     def relevant_webhooks() -> models.QuerySet:
         """Webhooks relevant for processing fuel notifications based on this config."""
@@ -1199,3 +1184,122 @@ class FuelAlertConfig(models.Model):
             )
             .distinct()
         )
+
+
+class JumpFuelAlertConfig(BaseFuelAlertConfig):
+    """Configuration of jump fuel notifications."""
+
+    threshold = models.PositiveIntegerField(
+        help_text=(
+            "Notifications will be sent once fuel level in units reaches this threshold"
+        )
+    )
+
+    def save(self, *args, **kwargs) -> None:
+        try:
+            old_instance = JumpFuelAlertConfig.objects.get(pk=self.pk)
+        except JumpFuelAlertConfig.DoesNotExist:
+            old_instance = None
+        super().save(*args, **kwargs)
+        if old_instance and (old_instance.threshold != self.threshold):
+            self.jump_fuel_alerts.all().delete()
+
+    def send_new_notifications(self, force: bool = False) -> None:
+        """Send new fuel notifications based on this config."""
+        jump_gates = Structure.objects.filter(
+            eve_type_id=constants.EVE_TYPE_ID_JUMP_GATE
+        )
+        for jump_gate in jump_gates:
+            if jump_gate.jump_fuel_quantity() < self.threshold:
+                notif, created = JumpFuelAlert.objects.get_or_create(
+                    structure=jump_gate, config=self
+                )
+                if created or force:
+                    notif.send_generated_notification()
+
+    @staticmethod
+    def relevant_webhooks() -> models.QuerySet:
+        """Webhooks relevant for processing jump fuel notifications based on this config."""
+        return Webhook.objects.filter(
+            owner__isnull=False,
+            is_active=True,
+            notification_types__contains=NotificationType.STRUCTURE_JUMP_FUEL_ALERT,
+        )
+
+
+class BaseFuelAlert(models.Model):
+    class Meta:
+        abstract = True
+
+    def send_generated_notification(self):
+        raise NotImplementedError()
+
+
+class FuelAlert(BaseFuelAlert):
+    """A generated notification alerting about fuel getting low in structures."""
+
+    structure = models.ForeignKey(
+        "Structure", on_delete=models.CASCADE, related_name="structure_fuel_alerts"
+    )
+    config = models.ForeignKey(
+        "FuelAlertConfig",
+        on_delete=models.CASCADE,
+        related_name="structure_fuel_alerts",
+    )
+    hours = models.PositiveIntegerField(
+        db_index=True,
+        help_text="number of hours before fuel expiration this alert was sent",
+    )
+
+    class Meta:
+        verbose_name = "structure fuel alert"
+        constraints = [
+            models.UniqueConstraint(
+                fields=["structure", "config", "hours"],
+                name="functional_pk_fuelalert",
+            )
+        ]
+
+    def __str__(self) -> str:
+        return f"{self.structure}-{self.config}-{self.hours}"
+
+    def send_generated_notification(self):
+        notif_type = (
+            NotificationType.TOWER_RESOURCE_ALERT_MSG
+            if self.structure.is_starbase
+            else NotificationType.STRUCTURE_FUEL_ALERT
+        )
+        notif = Notification.create_from_structure(
+            structure=self.structure, notif_type=notif_type
+        )
+        notif.send_to_configured_webhooks(
+            ping_type_override=self.config.channel_ping_type,
+            use_color_override=True,
+            color_override=self.config.color,
+        )
+
+
+class JumpFuelAlert(BaseFuelAlert):
+    """A generated notification alerting about jump fuel getting low."""
+
+    structure = models.ForeignKey(
+        "Structure", on_delete=models.CASCADE, related_name="jump_fuel_alerts"
+    )
+    config = models.ForeignKey(
+        "JumpFuelAlertConfig", on_delete=models.CASCADE, related_name="jump_fuel_alerts"
+    )
+
+    def __str__(self) -> str:
+        return f"{self.structure}-{self.config}"
+
+    def send_generated_notification(self) -> None:
+        notif = Notification.create_from_structure(
+            structure=self.structure,
+            notif_type=NotificationType.STRUCTURE_JUMP_FUEL_ALERT,
+            threshold=self.config.threshold,
+        )
+        notif.send_to_configured_webhooks(
+            ping_type_override=self.config.channel_ping_type,
+            use_color_override=True,
+            color_override=self.config.color,
+        )
