@@ -5,6 +5,7 @@ from typing import Optional
 
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
+from django.db.models import Sum
 from django.utils.functional import cached_property
 from django.utils.html import escape
 from django.utils.timezone import now
@@ -16,7 +17,7 @@ from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 from app_utils.views import bootstrap_label_html
 
-from .. import __title__
+from .. import __title__, constants
 from ..app_settings import STRUCTURES_FEATURE_REFUELED_NOTIFICIATIONS
 from ..helpers.general import datetime_almost_equal, hours_until_deadline
 from ..managers import StructureManager, StructureTagManager
@@ -336,15 +337,15 @@ class Structure(models.Model):
         # make sure related objects are saved whenever structure is saved
         self.update_generated_tags()
 
-    @property
+    @cached_property
     def is_upwell_structure(self) -> bool:
         return self.eve_type.is_upwell_structure
 
-    @property
+    @cached_property
     def is_poco(self) -> bool:
         return self.eve_type.is_poco
 
-    @property
+    @cached_property
     def is_starbase(self) -> bool:
         return self.eve_type.is_starbase
 
@@ -445,6 +446,13 @@ class Structure(models.Model):
             return self.eve_planet.name
         return self.eve_solar_system.name
 
+    def jump_fuel_quantity(self) -> Optional[int]:
+        """Current quantity of liquid ozone in units."""
+        return self.items.filter(
+            location_flag=StructureItem.LocationFlag.STRUCTURE_FUEL,
+            eve_type=constants.EVE_TYPE_ID_LIQUID_OZONE,
+        ).aggregate(Sum("quantity"))["quantity__sum"]
+
     @property
     def hours_fuel_expires(self) -> Optional[float]:
         """Hours until fuel expires."""
@@ -500,7 +508,7 @@ class Structure(models.Model):
                     "Therefore removing current fuel notifications.",
                     logger_tag,
                 )
-                self.fuel_alerts.all().delete()
+                self.structure_fuel_alerts.all().delete()
                 if STRUCTURES_FEATURE_REFUELED_NOTIFICIATIONS and (
                     not old_instance.fuel_expires_at
                     or old_instance.fuel_expires_at < self.fuel_expires_at
@@ -522,6 +530,14 @@ class Structure(models.Model):
         )
         notif.send_to_configured_webhooks()
 
+    def reevaluate_jump_fuel_alerts(self):
+        """Remove outdated fuel alerts based on potentially changed fuel levels."""
+        jump_fuel_quantity = self.jump_fuel_quantity()
+        if jump_fuel_quantity:
+            self.jump_fuel_alerts.filter(
+                config__threshold__lt=jump_fuel_quantity
+            ).delete()
+
     def get_power_mode_display(self) -> str:
         return self.PowerMode(self.power_mode).label if self.power_mode else ""
 
@@ -557,6 +573,51 @@ class Structure(models.Model):
         return matches.group(1) if matches else esi_name
 
 
+class StructureItem(models.Model):
+    """An item in a structure"""
+
+    class LocationFlag(models.TextChoices):
+        """Frequently used location flags.
+        This are not all, so can not be used as choices.
+        """
+
+        AUTOFIT = "AutoFit"
+        CARGO = "Cargo"
+        CORP_DELIVERIES = "CorpDeliveries"
+        FIGHTER_BAY = "FighterBay"
+        OFFICE_FOLDER = "OfficeFolder"
+        QUANTUM_CORE_ROOM = "QuantumCoreRoom"
+        SECONDARY_STORAGE = "SecondaryStorage"
+        STRUCTURE_FUEL = "StructureFuel"
+
+    id = models.BigIntegerField(primary_key=True, help_text="The Eve item ID")
+    structure = models.ForeignKey(
+        "Structure",
+        on_delete=models.CASCADE,
+        related_name="items",
+        help_text="Structure this item is located in",
+    )
+
+    eve_type = models.ForeignKey(
+        "EveType",
+        on_delete=models.CASCADE,
+        help_text="eve type of the item",
+        related_name="+",
+    )
+    is_singleton = models.BooleanField(null=False)
+    last_updated_at = models.DateTimeField(auto_now=True)
+    location_flag = models.CharField(max_length=255)
+    quantity = models.IntegerField(null=False)
+
+    def __str__(self) -> str:
+        return str(self.eve_type.name)
+
+    def __repr__(self):
+        return "{}(pk={}, structure=<{}>, eve_type=<{}>)".format(
+            self.__class__.__name__, self.pk, self.structure, self.eve_type
+        )
+
+
 class StructureService(EsiNameLocalization, models.Model):
     """service of a structure"""
 
